##  Discovery and Integrations
The Discovery and Integrations category in the administration area includes sections listed in the following table.
Section | Description | Related Information
---|---|---
API Tokens | Important: Personal API tokens are deprecated. Use Technical Users instead. In this section, you can find values of the WorkspaceId and UserId attributes. |  [Technical Users](https://help.sap.com/docs/leanix/ea/technical-users?locale=en-US&state=PRODUCTION&version=CLOUD "To get an API token, create a technical user. Manage technical users collaboratively with other administrators.")
Developer Tools | Resources relevant for developers: developer guide, GraphiQL tool, and OpenAPI Explorer for REST APIs. |  [Developer guide](https://help.sap.com/docs/leanix/ea/developer-guide?locale=en-US&state=PRODUCTION&version=CLOUD "Resources for developers working with SAP LeanIX.") [GraphQL API](https://help.sap.com/docs/leanix/ea/graphql-api?locale=en-US&state=PRODUCTION&version=CLOUD "Get started with the SAP LeanIX GraphQL API.") [REST APIs](https://help.sap.com/docs/leanix/ea/rest-apis?locale=en-US&state=PRODUCTION&version=CLOUD "Get started with SAP LeanIX REST APIs.")
Integrations | Configure discovery solutions and out-of-the-box integrations. |  [Discovery and Integrations](https://help.sap.com/docs/leanix/ea/discovery-and-integrations?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how SAP LeanIX integrates with various systems, automates data syncing, enhances collaboration, and provides the reference catalog to ensure accurate and up-to-date information in your workspace.")
Integration API | Configure and run Integration API processors. |  [Integration API](https://help.sap.com/docs/leanix/ea/integration-api?locale=en-US&state=PRODUCTION&version=CLOUD "Overview of the Integration API.")
Metrics | Configure custom metrics and KPIs using time series data. |  [Metrics](https://help.sap.com/docs/leanix/ea/metrics?locale=en-US&state=PRODUCTION&version=CLOUD "Metrics help you to display KPIs and their development over time in the context of the right Fact Sheet.")
Self-Built Software Discovery | Provision the workspace for self-built software discovery. |  [Self-Built Software Discovery](https://help.sap.com/docs/leanix/ea/self-built-software-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX Technology Risk and Compliance enables you to automate the discovery of your self-built software by integrating this process into your developer toolchain.") [Workspace Setup for Self-Built Software Discovery](https://help.sap.com/docs/leanix/ea/workspace-setup-for-self-built-software-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "Provision the self-built software discovery feature in SAP LeanIX to enable microservice discovery. This extends the meta model with microservice fact sheets, custom relations, and additional context fields.")
Reference Catalog | Configure settings of the reference catalog and import best-practice data from the catalog. |  [Reference Catalog](https://help.sap.com/docs/leanix/ea/reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "The reference catalog provides reference data for business capabilities, applications, IT components, and tech categories, which enables you to set up and maintain your inventory more efficiently.")
Tech Stack Discovery | Explore tech stacks from the reference catalog and view matching (discovered) tech stacks for your ingested SBOM components. | [Tech Stack Discovery from SBOMs](https://help.sap.com/docs/leanix/ea/tech-stack-discovery-from-sboms?locale=en-US&state=PRODUCTION&version=CLOUD "Automatically discover tech stacks from ingested SBOMs. Add custom tech stacks manually to complete your technology portfolio.")
Sync Logging | View synchronization logs of integrations. |  [Synchronization Logging](https://help.sap.com/docs/leanix/ea/synchronization-logging?locale=en-US&state=PRODUCTION&version=CLOUD "Use synchronization logs to track the state of your integrations.")
Technical Users | Create and manage Technical Users associated with API tokens. |  [Technical Users](https://help.sap.com/docs/leanix/ea/technical-users?locale=en-US&state=PRODUCTION&version=CLOUD "To get an API token, create a technical user. Manage technical users collaboratively with other administrators.")
Webhooks | Configure webhooks to listen to events in SAP LeanIX. |  [Webhooks](https://help.sap.com/docs/leanix/ea/webhooks?locale=en-US&state=PRODUCTION&version=CLOUD "Listen to events in SAP LeanIX using webhooks.")


YesNo
Send
